@@ -1,7 +1,7 @@
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
 
-use MDiff;
+use Algorithm::MDiff;
 
 $loaded = 1;
 print "ok 1\n";
